==> flowable-cmmn-api-7.0.1-sources.jar: org/flowable/cmmn/api/migration/CaseInstanceMigrationDocument.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.cmmn.api.migration;

import java.util.List;
import java.util.Map;

/**
 * @author Valentin Zickner
 */
public interface CaseInstanceMigrationDocument {

    String getMigrateToCaseDefinitionId();

    String getMigrateToCaseDefinitionKey();

    Integer getMigrateToCaseDefinitionVersion();

    String getMigrateToCaseDefinitionTenantId();

    List<ActivatePlanItemDefinitionMapping> getActivatePlanItemDefinitionMappings();
    
    List<TerminatePlanItemDefinitionMapping> getTerminatePlanItemDefinitionMappings();
    
    List<MoveToAvailablePlanItemDefinitionMapping> getMoveToAvailablePlanItemDefinitionMappings();
    
    List<WaitingForRepetitionPlanItemDefinitionMapping> getWaitingForRepetitionPlanItemDefinitionMappings();
    
    List<RemoveWaitingForRepetitionPlanItemDefinitionMapping> getRemoveWaitingForRepetitionPlanItemDefinitionMappings();
    
    List<ChangePlanItemIdMapping> getChangePlanItemIdMappings();
    
    List<ChangePlanItemIdWithDefinitionIdMapping> getChangePlanItemIdWithDefinitionIdMappings();

    String getPreUpgradeExpression();

    String getPostUpgradeExpression();

    Map<String, Map<String, Object>> getPlanItemLocalVariables();

    Map<String, Object> getCaseInstanceVariables();

    String asJsonString();

}

==> flowable-cmmn-api-7.2.0-sources.jar: org/flowable/cmmn/api/migration/CaseInstanceMigrationDocument.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.cmmn.api.migration;

import java.util.List;
import java.util.Map;

/**
 * @author Valentin Zickner
 */
public interface CaseInstanceMigrationDocument {

    String getMigrateToCaseDefinitionId();

    String getMigrateToCaseDefinitionKey();

    Integer getMigrateToCaseDefinitionVersion();

    String getMigrateToCaseDefinitionTenantId();

    List<ActivatePlanItemDefinitionMapping> getActivatePlanItemDefinitionMappings();
    
    List<TerminatePlanItemDefinitionMapping> getTerminatePlanItemDefinitionMappings();
    
    List<MoveToAvailablePlanItemDefinitionMapping> getMoveToAvailablePlanItemDefinitionMappings();
    
    List<WaitingForRepetitionPlanItemDefinitionMapping> getWaitingForRepetitionPlanItemDefinitionMappings();
    
    List<RemoveWaitingForRepetitionPlanItemDefinitionMapping> getRemoveWaitingForRepetitionPlanItemDefinitionMappings();
    
    List<ChangePlanItemIdMapping> getChangePlanItemIdMappings();
    
    List<ChangePlanItemIdWithDefinitionIdMapping> getChangePlanItemIdWithDefinitionIdMappings();
    
    List<ChangePlanItemDefinitionWithNewTargetIdsMapping> getChangePlanItemDefinitionWithNewTargetIdsMappings();

    String getPreUpgradeExpression();

    String getPostUpgradeExpression();

    Map<String, Map<String, Object>> getPlanItemLocalVariables();

    Map<String, Object> getCaseInstanceVariables();

    String asJsonString();

}
